/**
 * Crud 组件的接口声明
 */
export interface RootStateTypes {
    themeConfig: ThemeConfigState;
    crudOptionsConfig: CrudOptionsConfigState;
    columns: CrudColumn;
    CrudOptions: CrudOptions;
}
/** 对 columns 数据拆分*/
export interface ElementArrsType {
    filter: any[];
    editor: any[];
    column: any[];
}
/** 系统参数 */
export interface OptionsType {
    /** 表单标签宽度 */
    labelWidth: number;
    /** 显示操作菜单 */
    showMenu: boolean;
    /** 操作菜单宽度 */
    menuWidth: number;
    /** 操作菜单对齐方式 */
    menuAlign: 'left' | 'center' | 'right';
    /** 表格分页大小 */
    pageSizes: number[];
    /** 搜索表单折叠 */
    searchFormCollapse: boolean;
    /** 显示新增按钮 */
    showAddSubmitBut: boolean;
    /** 显示刷新按钮 */
    showRefresh: boolean;
    /**接口 name 名称 */
    apiName: ReqnameType;
    /** 页面权限 */
    permission: ReqnameType;
}
/** 接口 name 默认名称 必填 */
export interface ReqnameType {
    /** 查询 */
    query: string;
    /** 新增 */
    add: string;
    /** 编辑 */
    edit: string;
    /** 单条删除 */
    delete: string;
    /** 标记删除 [启用 / 禁用] */
    deleteFlag: string;
    /** 多选删除 */
    remove: string;
}
/** 接口 name 默认名称 可选 */
export interface OptnameType {
    /** 查询 */
    query?: string;
    /** 新增 */
    add?: string;
    /** 编辑 */
    edit?: string;
    /** 单条删除 */
    delete?: string;
    /** 标记删除 [启用 / 禁用] */
    deleteFlag?: string;
    /** 多选删除 */
    remove?: string;
}
interface span {
    span?: number;
    sm?: number;
    md?: number;
    lg?: number;
}
interface include {
    filter: string;
    editor: string;
    column: string;
}
interface Prop {
    [x: string]: any;
}
export interface ThemeConfigState {
    settingConfig: {
        AppTitle: String;
        AppLogo: String;
    };
}
export interface CrudOptionsConfigState {
    columns: Array<CrudColumn>;
    options: CrudOptions;
}
interface CrudColumn {
    group?: string;
    type: string;
    label: string;
    prop?: string;
    rules?: any;
    auto?: string;
    align?: string;
    searchDefaultValue?: any;
    addDefaultValue?: any;
    span?: span;
    hidden?: boolean;
    include: (keyof include)[];
    visible?: (a: any, b: string) => boolean;
    formProps?: Prop;
    tableProps?: Prop;
    columnSlot?: Prop;
}
interface CrudOptions {
    id: String;
    apiName?: OptnameType;
    permission?: OptnameType;
    pageSizes?: Array<number>;
    labelWidth?: number;
    searchButCollapse?: boolean;
    searchShowNums?: number;
    hideRefresh?: boolean;
    hidAddSubmitBut?: boolean;
    showActionBar?: boolean;
    menuWidth?: number;
    menuAlign?: string;
}
export {};
