import { $CrudRequest } from '../utils/api'

/** 系统默认参数 */
const Options: OptionsType = {
    apiName: {
        query: 'query',
        add: 'add',
        edit: 'edit',
        delete: 'delete',
        deleteFlag: 'deleteFlag',
        remove: 'remove'
    },

    permission: {
        query: 'query',
        add: 'add',
        edit: 'edit',
        delete: 'delete',
        deleteFlag: 'deleteFlag',
        remove: 'remove'
    },
    menuWidth: 311,
    pageSizes: [10, 20, 50, 100],
    labelWidth: 100,
    menuAlign: 'left',
    searchFormCollapse: true,
    showMenu: false,
    showAddSubmitBut: false,
    showRefresh: false
}

let CrudRequest: Function = $CrudRequest

let defaultOptions = {}

/** 初始化系统参数 */
const InitOptions = (options?: OptionsType) => {
    const connectedProps = { ...options }
    let opt: any = {}
    Object.keys(connectedProps).forEach((key: any) => {
        if (key === 'CrudRequest') {
            CrudRequest = options!.CrudRequest!
        } else {
            // @ts-ignore
            opt[key] = options[key]
        }
    })
    defaultOptions = DataMerger(Options, opt)
}

/***********************************   方法   *********************************** */

/**
 * 深拷贝
 * @param Obj 需要拷贝的数据对象
 * @returns 一个新的数据对象
 */
function DeepClone(Obj: any) {
    let newObj: any

    try {
        newObj = Array.isArray(Obj) ? [] : {}
        if (Obj === null) newObj = null
    } catch (error) {
        newObj = {}
    }

    for (const attr in Obj) {
        if (typeof Obj[attr] === 'object') {
            newObj[attr] = DeepClone(Obj[attr])
        } else {
            newObj[attr] = Obj[attr]
        }
    }

    return newObj
}

/**
 * 数据合并
 * @param Obj1 原数据
 * @param Obj2 需要合并进来的数据
 * @returns
 */
function DataMerger(Obj1: any, Obj2?: { [x: string]: any }) {
    let newObj = DeepClone(Obj1)

    for (var key in Obj2) {
        if (newObj.hasOwnProperty(key)) {
            if (typeof Obj2[key] === 'object') {
                newObj[key] = DataMerger(newObj[key], Obj2[key])
            } else {
                newObj[key] = Obj2[key]
            }
        } else {
            newObj[key] = Obj2[key]
        }
    }
    return newObj
}
/***********************************   方法   *********************************** */

export { defaultOptions, InitOptions, DeepClone, DataMerger, CrudRequest }
