import { reactive } from 'vue'
// 钩子对象约束
interface HooksObject {
    [key: string]: any
}

// 钩子配置对象约束
interface HooksConfig {
    debug?: boolean
    [key: string]: any
}

// 支持的钩子对象
const hooksName = {
    /**提交之前 */
    beforeSubmitHandler: 'beforeSubmitHandler',

    /** 启用/禁用之前 */
    beforedisabledHandler: 'beforedisabledHandler',
    /** 启用/禁用之后 */
    afterdisabledHandler: 'afterdisabledHandler',

    /** 新增之前 */
    beforeAddHandler: 'beforeAddHandler',
    /** 编辑之前 */
    beforeEditHandler: 'beforeEditHandler',

    /** 查询之前 */
    beforeQueryHandler: 'beforeQueryHandler',
    /** 查询之后 */
    afterQueryHandler: 'afterQueryHandler',

    /** 删除之前 */
    beforeDeteleHandler: 'beforeDeteleHandler',
    /** 删除之后 */
    afterDeteleHandler: 'afterDeteleHandler',

    // 表格懒加载之前
    beforeTableLazyHandler: 'beforeTableLazyHandler'
}

/**
 * 注册钩子
 * @param hooks 组件注册的钩子对象
 * @returns 返回钩子处理函数及钩子名称
 */
function useHooks(hooks: HooksConfig = { debug: false }) {
    // 当前实例的钩子
    const state: HooksObject = reactive({
        hooks: {}
    })

    // 向当前实例注册钩子
    Object.keys(hooks).forEach((item) => {
        if (item !== 'debug') {
            state.hooks[item] = hooks[item]
        }
    })

    /**
     * 处理钩子函数
     * @param hookName 钩子名称
     * @param data 钩子接收的响应式数据
     * @returns 返回处理结果
     */
    const hookHandler = (hookName: string, data: Object) => {
        let res = false
        try {
            if (hooks.debug) {
                console.log(`Crud Hooks Debug：${hookName}`)
                console.table(data)
                console.log(`Crud Hooks Debug：${hookName}`)
            }
            res = state.hooks[hookName](data)
        } catch (error) {
            res = true
        }
        return res
    }

    return {
        hookHandler
    }
}

export { hooksName, useHooks }
export type { HooksConfig }
