/**
 * Crud 组件的接口声明
 */

// 主接口(顶级类型声明)
export interface RootStateTypes {
    themeConfig: ThemeConfigState // 布局配置
    crudOptionsConfig: CrudOptionsConfigState // CRUD 的配置
    columns: CrudColumn // Crud 组件 column 的配置
    CrudOptions: CrudOptions
}

/** 对 columns 数据拆分*/
export interface ElementArrsType {
    filter: any[]
    editor: any[]
    column: any[]
}

/** 系统参数 */
export interface OptionsType {
    /** 表单标签宽度 */
    labelWidth: number
    /** 显示操作菜单 */
    showMenu: boolean
    /** 操作菜单宽度 */
    menuWidth: number
    /** 操作菜单对齐方式 */
    menuAlign: 'left' | 'center' | 'right'
    /** 表格分页大小 */
    pageSizes: number[]
    /** 搜索表单折叠 */
    searchFormCollapse: boolean
    /** 显示新增按钮 */
    showAddSubmitBut: boolean
    /** 显示刷新按钮 */
    showRefresh: boolean
    /**接口 name 名称 */
    apiName: ReqnameType
    /** 页面权限 */
    permission: ReqnameType
}

/** 接口 name 默认名称 必填 */
export interface ReqnameType {
    /** 查询 */
    query: string
    /** 新增 */
    add: string
    /** 编辑 */
    edit: string
    /** 单条删除 */
    delete: string
    /** 标记删除 [启用 / 禁用] */
    deleteFlag: string
    /** 多选删除 */
    remove: string
}
/** 接口 name 默认名称 可选 */
export interface OptnameType {
    /** 查询 */
    query?: string
    /** 新增 */
    add?: string
    /** 编辑 */
    edit?: string
    /** 单条删除 */
    delete?: string
    /** 标记删除 [启用 / 禁用] */
    deleteFlag?: string
    /** 多选删除 */
    remove?: string
}

interface span {
    span?: number
    sm?: number
    md?: number
    lg?: number
}
interface include {
    filter: string
    editor: string
    column: string
}

interface Prop {
    [x: string]: any
}

// 布局配置
export interface ThemeConfigState {
    settingConfig: {
        AppTitle: String
        AppLogo: String
    }
}

// Crud 组件的配置
export interface CrudOptionsConfigState {
    columns: Array<CrudColumn>
    options: CrudOptions
}

// Crud 组件 column 的配置
interface CrudColumn {
    group?: string // 分组标签
    type: string // 创建的组件名
    label: string // 表单的 label
    prop?: string // 数据值绑定
    rules?: any // 校验规则
    auto?: string // 列的权限
    align?: string // 列对齐方向
    searchDefaultValue?: any // 初始化搜索时的默认值
    addDefaultValue?: any // 新增操作时的默认值
    span?: span // 表单的栅格占据的列数对象
    hidden?: boolean // 是否隐藏
    include: (keyof include)[] // 过滤需要展示的 item
    visible?: (a: any, b: string) => boolean
    formProps?: Prop // 表单的参数配置
    tableProps?: Prop // 表格的配置
    columnSlot?: Prop // 表格自定义格式化的配置
}

// Crud 组件 options 的配置
interface CrudOptions {
    id: String // 权限的拼接参数 v-permission="addUser" ==> add【permission】 + User【id】
    apiName?: OptnameType // 请求接口对象
    permission?: OptnameType // 权限对象

    pageSizes?: Array<number> // 分页的大小
    labelWidth?: number // 表单 label 文字宽度
    searchButCollapse?: boolean // 搜索框是否默认为收起状态
    searchShowNums?: number // 表单收起时显示的值
    hideRefresh?: boolean //是否隐藏刷新按钮
    hidAddSubmitBut?: boolean // 隐藏新增、修改对话框的提交按钮
    showActionBar?: boolean // 显示表格的操作栏

    menuWidth?: number // 表格操作菜单宽度
    menuAlign?: string // 表格操作菜单对齐方式
}
